LoggerConfig

Struct LoggerConfig 

pub struct LoggerConfig<L: LogLevel> {
    pub file: Option<PathBuf>,
    pub append: bool,
    pub stdout: bool,
    pub stderr: bool,
    pub log: Option<LogCrateLevel>,
    pub level: L,
}
Configuration for a log sink, parameterized by a subsystem-specific log level.

Multiple sinks can be enabled at the same time (e.g. both stdout and a file).

Fields

file: Option<PathBuf>

Path to the log file, if file logging is enabled (requires filesystem access).

append: bool

Whether to append to the log file (true) or overwrite it (false). Defaults to true.

Notes

This parameter might get ignored based on other loggers config.

stdout: bool

Whether to log to standard output.

stderr: bool

Whether to log to standard error.

log: Option<LogCrateLevel>

Optional crate-level logging configuration (e.g., info, debug, trace).

level: L

The verbosity level for this subsystem.