Crate cubecl_common

Crate cubecl_common 

CubeCL Common Library

This library contains common types used by other crates that must be shared.

Modules

arena
A circular, allocation-free arena for reusable memory blocks.
backtrace
Backtrace module to build error reports.
benchmark
Module for benchmark timings
device
Device module.
device_handle
Device handle module.
format
Format utilities.
future
Future utils with a compatible API for native, non-std and wasm environments.
map
Map utilities and implementations.
profile
Module for profiling any executable part
quant
Quantization primitives required outside of cubecl-quant
rand
Rand module contains types for random number generation for non-std environments and for std environments.
reader
Useful when you need to read async data without having to decorate each function with async notation.
stream_id
Stream id related utilities.
stub
Stub module contains types for stubs for non-std environments and for std environments.

Structs

e2m3
A 6-bit floating point type with 2 exponent bits and 3 mantissa bits.
e3m2
A 6-bit floating point type with 3 exponent bits and 2 mantissa bits.
flex32
A floating point type with relaxed precision, minimum f16, max f32.
tf32
A 19-bit floating point type implementing the tfloat32 format.