Useful when you need to read async data without having to decorate each function with async notation.
Functions
- Read a future synchronously.
- Read a future synchronously.
Useful when you need to read async data without having to decorate each function with async notation.