Reusable logger configuration and sink management.
Structs
- Logger
Config - Configuration for a log sink, parameterized by a subsystem-specific log level.
- Logger
Sinks - Registry of log sinks, deduplicating by output target so that multiple subsystems can share a single file or stdout/stderr stream.
Enums
- LogCrate
Level - Log levels forwarded to the
logcrate.
Traits
- LogLevel
- Trait for types usable as a subsystem-specific log level.